@@ -1,4 +1,4 @@
-# Copyright 2018 Nir Harel
+# Copyright 2020 Nir Harel
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -12,22 +12,27 @@
 #    See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Unused at the moment. Will add exceptions later.
+
+class LlException(Exception):
+    """The base class for all exceptions emitted by the library"""
+    def __init__(self, message: str = "There was an unspecified exception regarding the LaunchLibrary wrapper."):
+        super().__init__(message)
 
 
-class ApiException(Exception):
+class ApiException(LlException):
+    """An exception related to the API's response"""
     def __init__(self, message: str = "There was an unknown issue with the API. Please reevaluate your call."):
         super().__init__(message)
 
 
-class NetworkException(Exception):
-    """Some type of network failure unrelated to the request, like the connection timing out"""
+class NetworkException(LlException):
+    """Some network failure that's unrelated to the request, like a dropped connection"""
 
     def __init__(self, message: str):
         super().__init__(message)
 
 
-class TimeoutException(Exception):
+class TimeoutException(LlException):
     """All timeout failures, both during the initial connection and subsequent messages"""
 
     def __init__(self, message: str = ""):
